@@ -271,7 +271,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="id/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
     <li><a target="_top" href="id/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
 			</ul></li>\
-    <li><input type="checkbox" id="070205"><label for="070205">Advanced Basic Libraries</label><ul>\
+    <li><input type="checkbox" id="070205"><label for="070205">Pustaka Dasar Lanjutan</label><ul>\
     <li><a target="_top" href="id/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
     <li><a target="_top" href="id/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
     <li><a target="_top" href="id/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
@@ -419,7 +419,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="id/text/scalc/guide/datapilot_tipps.html">Memilih Jangkauan Basis Data</a></li>\
     <li><a target="_top" href="id/text/scalc/guide/datapilot_updatetable.html">Menyunting Tabel di dalam Teks</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="08091"><label for="08091">Pivot Chart</label><ul>\
+    <li><input type="checkbox" id="08091"><label for="08091">Bagan Pivot</label><ul>\
     <li><a target="_top" href="id/text/scalc/guide/pivotchart.html">Pivot Chart</a></li>\
     <li><a target="_top" href="id/text/scalc/guide/pivotchart_create.html">Creating Pivot Charts</a></li>\
     <li><a target="_top" href="id/text/scalc/guide/pivotchart_edit.html">Editing Pivot Charts</a></li>\
@@ -567,7 +567,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="id/text/shared/guide/textmode_change.html">Switching Between Insert Mode and Overwrite Mode</a></li>\
     <li><a target="_top" href="id/text/shared/guide/floating_toolbar.html">Using Toolbars</a></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="10071"><label for="10071">Digital Signatures</label><ul>\
+    <li><input type="checkbox" id="10071"><label for="10071">Tanda tangan Digital</label><ul>\
     <li><a target="_top" href="id/text/shared/guide/digital_signatures.html">About Digital Signatures</a></li>\
     <li><a target="_top" href="id/text/shared/guide/digitalsign_send.html">Applying Digital Signatures</a></li>\
     <li><a target="_top" href="id/text/shared/01/digitalsignaturespdf.html">Digital Signature in PDF Export</a></li>\
@@ -684,7 +684,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="id/text/simpress/guide/keyboard.html">Menggunakan Tombol Pintas di LibreOffice Impress</a></li>\
     <li><a target="_top" href="id/text/sdraw/guide/keyboard.html">Tombol Pintas untuk Objek Menggambar</a></li>\
     <li><a target="_top" href="id/text/simpress/04/01020000.html">Tombol Pintas untuk LibreOffice Impress</a></li>\
-    <li><a target="_top" href="id/text/simpress/04/presenter.html">Presenter Console Keyboard Shortcuts</a></li>\
+    <li><a target="_top" href="id/text/simpress/04/presenter.html">Pintasan Papan Ketik Konsol Penyaji</a></li>\
     <li><a target="_top" href="id/text/sdraw/04/01020000.html">Tombol Pintas untuk Menggambar</a></li>\
     <li><a target="_top" href="id/text/simpress/guide/main.html">Instruksi bagi Penggunaan LibreOffice Impress</a></li>\
     <li><a target="_top" href="id/text/sdraw/guide/main.html">Instruksi untuk Menggunakan LibreOffice Draw</a></li>\
